#!/bin/sh
# $Id: lxc-dialog,v 0.13 2011/03/16 10:09:05 geordy $


#Setup variables
: ${DIALOG=dialog}
: ${DIALOG_OK=0}
: ${DIALOG_CANCEL=1}
: ${DIALOG_HELP=2}
: ${DIALOG_EXTRA=3}
: ${DIALOG_ITEM_HELP=4}
: ${DIALOG_ESC=255}

#Setup temporary files
tempfile=`tempfile 2>/dev/null` || tempfile=/tmp/test$$
trap "rm -f $tempfile" 0 1 2 5 15

# Find all LXC containers
lxcpath=/var/lib/lxc
machine_list=


WORK_MENU ()
{
bail_out=
while [ "$bail_out" != "YES" ]
do
	$DIALOG --clear --title "LXC Management" "$@" \
       		--menu "Please choose operation for $lxc_machine" 20 51 10 \
			"Console" "Open local Getty Console" \
			"Start" "Start the container"\
			"Stop" "Stop the container" 2> $tempfile
	retval=$?
	case $retval in
	  $DIALOG_OK)
		lxc_task=`cat $tempfile`
		case $lxc_task in
			"Console")
				echo STARTING CONSOLE
				lxc-console --name $lxc_machine
				;;
			"Start")
				echo START
				lxc-start --name $lxc_machine -d
				;;
			"Stop")
				echo STOP
				lxc-stop --name $lxc_machine
				;;
			esac
		echo "Result: `cat $tempfile`"
	    	;;
	  $DIALOG_CANCEL)
	    echo "Cancel pressed."
		bail_out="YES"
		;;
	  $DIALOG_HELP)
	    echo "Help pressed.";;
	  $DIALOG_EXTRA)
	    echo "Extra button pressed.";;
	  $DIALOG_ITEM_HELP)
	    echo "Item-help button pressed.";;
	  $DIALOG_ESC)
	    if test -s $tempfile ; then
	      cat $tempfile
	    else
	      echo "ESC pressed."
		bail_out="YES"
	    fi
	    ;;
	esac
done
bail_out=
}
FIND_CONTAINERS ()
{
	machine_list=
	for i in `ls -l $lxcpath | grep ^d | sed "s/.* //"`; do
		status=`lxc-info --name $i| sed "s/.* //"`
		machine_list=$machine_list" $i $status"
	done
}

MAIN_MENU ()
{
bail_out=
while [ "$bail_out" != "YES" ]
do
	FIND_CONTAINERS
	$DIALOG --clear --title "LXC Management" "$@" \
       		--menu "Please select the LXC container you would like to manage" 20 51 10 $machine_list 2> $tempfile
	retval=$?

	case $retval in
	  $DIALOG_OK)
		lxc_machine=`cat $tempfile`		
		WORK_MENU
	    	;;
	  $DIALOG_CANCEL)
	    echo "Cancel pressed."
		bail_out="YES"
		;;
	  $DIALOG_HELP)
	    echo "Help pressed.";;
	  $DIALOG_EXTRA)
	    echo "Extra button pressed.";;
	  $DIALOG_ITEM_HELP)
	    echo "Item-help button pressed.";;
	  $DIALOG_ESC)
	    if test -s $tempfile ; then
	      cat $tempfile
	    else
	      echo "ESC pressed."
		bail_out="YES"

	    fi
	    ;;
	esac
done
}


MAIN_MENU
exit 1
